@@ -112,6 +112,8 @@ DISPLAY_HAS_SCREEN_INDEX = POSIX and os.environ.get("DISPLAY", "").split(":")[-1
 HONOUR_SCREEN_MAPPING = envbool("XPRA_HONOUR_SCREEN_MAPPING", POSIX and not DISPLAY_HAS_SCREEN_INDEX) and not is_gtk3()
 DRAGNDROP = envbool("XPRA_DRAGNDROP", True)
 CLAMP_WINDOW_TO_SCREEN = envbool("XPRA_CLAMP_WINDOW_TO_SCREEN", True)
+REPAINT_MAXIMIZED = envint("XPRA_REPAINT_MAXIMIZED", 0)
+REFRESH_MAXIMIZED = envbool("XPRA_REFRESH_MAXIMIZED", True)
 
 WINDOW_OVERFLOW_TOP = envbool("XPRA_WINDOW_OVERFLOW_TOP", False)
 AWT_RECENTER = envbool("XPRA_AWT_RECENTER", True)
@@ -866,6 +868,17 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
                 self.process_map_event()
         statelog("window_state_updated(..) state updates: %s, actual updates: %s, server updates: %s",
                  state_updates, actual_updates, server_updates)
+        if "maximized" in state_updates:
+            if REPAINT_MAXIMIZED>0:
+                def repaint_maximized():
+                    if not self._backing:
+                        return
+                    ww, wh = self.get_size()
+                    #this should work for the non-opengl case:
+                    self.queue_draw_area(0, 0, ww, wh)
+                self.timeout_add(REPAINT_MAXIMIZED, repaint_maximized)
+            if REFRESH_MAXIMIZED:
+                self._client.send_refresh(self._id)
         self._window_state.update(server_updates)
         self.emit("state-updated")
         #if we have state updates, send them back to the server using a configure window packet:
@@ -1263,6 +1276,9 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
             #which will look at the window metadata again
             workspacelog("workspace=%s will be set when the window is mapped", wn(workspace))
             return
+        workspace = workspace
+        if workspace is not None:
+            workspace = workspace & 0xffffffff
         desktop = self.get_desktop_workspace()
         ndesktops = self.get_workspace_count()
         current = self.get_window_workspace()
@@ -1318,7 +1334,7 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
         value = self.xget_u32_property(target, prop)
         if value is not None:
             workspacelog("do_get_workspace %s=%s on window %#x", prop, wn(value), get_xwindow(target))
-            return value
+            return value & 0xffffffff
         workspacelog("do_get_workspace %s unset on window %#x, returning default value=%s",
                      prop, get_xwindow(target), wn(default_value))
         return  default_value
@@ -1761,7 +1777,10 @@ class GTKClientWindowBase(ClientWindowBase, gtk.Window):
             #we may have cleared the backing, so we must re-create one:
             self._set_backing_size(w, h)
         if not self._override_redirect:
-            self.idle_add(self._focus_change, "initial")
+            htf = self.has_toplevel_focus()
+            focuslog("mapped: has-toplevel-focus=%s", htf)
+            if htf:
+                self._client.update_focus(self._id, htf)
 
     def get_window_frame_size(self):
         frame = self._client.get_frame_extents(self)
