@@ -377,9 +377,13 @@ def getUbuntuVersion():
     return ()
 
 def is_unity():
-    return os.environ.get("XDG_CURRENT_DESKTOP", "").lower().find("unity")>=0
+    d = os.environ.get("XDG_CURRENT_DESKTOP", "").lower()
+    return d.find("unity")>=0 or d.find("ubuntu")>=0
 
 def is_gnome():
+    if os.environ.get("XDG_SESSION_DESKTOP", "").split("-", 1)[0] in ("i3", "ubuntu", ):
+        #"i3-gnome" is not really gnome... ie: the systray does work!
+        return False
     return os.environ.get("XDG_CURRENT_DESKTOP", "").lower().find("gnome")>=0
 
 def is_kde():
