@@ -17,7 +17,7 @@ from ctypes.wintypes import (
 from ctypes.wintypes import (
     HANDLE, LPSTR, LPCWSTR, UINT, INT, BOOL, WORD, HGDIOBJ,
     LONG, LPVOID, HBITMAP, LPCSTR, LPWSTR, HWINSTA,
-    HINSTANCE, HMENU, ULONG,
+    HINSTANCE, HMENU, ULONG, HHOOK, MSG,
     )
 #imported from this module but not used here:
 assert GetLastError
@@ -31,6 +31,7 @@ PBYTE = POINTER(BYTE)
 HCURSOR = HANDLE
 HICON = HANDLE
 HBRUSH = HANDLE
+LPMSG = POINTER(MSG)
 
 class CURSORINFO(Structure):
     _fields_ = [
@@ -234,7 +235,7 @@ UnregisterClassW.restype = BOOL
 UnregisterClassW.argtypes = [LPCWSTR, HINSTANCE]
 CreateWindowExA = user32.CreateWindowExA
 CreateWindowExA.restype = HWND
-#CreateWindowExA.argtypes = [DWORD, ATOM, LPCTSTR, DWORD, c_int, c_int, c_int, c_int, HWND, HMENU, HINSTANCE, LPVOID]
+CreateWindowExA.argtypes = [DWORD, ATOM, LPCWSTR, DWORD, c_int, c_int, c_int, c_int, HWND, HMENU, HINSTANCE, LPVOID]
 CreateWindowExW = user32.CreateWindowExW
 CreateWindowExW.restype = HWND
 CreateWindowExW.argtypes = [DWORD, ATOM, LPCWSTR, DWORD, c_int, c_int, c_int, c_int, HWND, HMENU, HINSTANCE, LPVOID]
@@ -284,10 +285,20 @@ GetMonitorInfoW.argtypes = [HMONITOR, POINTER(MONITORINFOEX)]
 GetMonitorInfoW.restype = BOOL
 UnhookWindowsHookEx = user32.UnhookWindowsHookEx
 CallNextHookEx = user32.CallNextHookEx
+CallNextHookEx.restype = LRESULT
+CallNextHookEx.argtyps = [HHOOK, INT, WPARAM, LPARAM]
 SetWindowsHookExA = user32.SetWindowsHookExA
+SetWindowsHookExA.restype = HHOOK
+SetWindowsHookExA.argtypes = [INT, HANDLE, HINSTANCE, DWORD]
 GetMessageA = user32.GetMessageA
+GetMessageA.restype = BOOL
+GetMessageA.argtypes = [LPMSG, HWND, UINT, UINT]
 TranslateMessage = user32.TranslateMessage
+TranslateMessage.restype = BOOL
+TranslateMessage.argtypes = [LPMSG]
 DispatchMessageA = user32.DispatchMessageA
+DispatchMessageA.restype = LRESULT
+DispatchMessageA.argtypes = [LPMSG]
 MapVirtualKeyW = user32.MapVirtualKeyW
 GetKeyboardState = user32.GetKeyboardState
 GetKeyboardState.argtypes = [PBYTE]
